@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-09-10'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2015-09-12'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,21 +49,19 @@ my %pericmd_attrs = (
           read_config config_dirs config_filename
          /),
 
-    summary => {
-        summary => 'Program summary',
-        schema  => 'str*',
-    },
     pass_cmdline_object => {
         summary => 'Whether to pass Perinci::CmdLine::Inline object',
         schema  => 'bool*',
         default => 0,
     },
-    program_name => {
-        summary => 'Program name',
+    script_name => {
         schema => 'str*',
     },
-    program_version => {
-        summary => 'Program version (otherwise will use version from url metadata)',
+    script_summary => {
+        schema => 'str*',
+    },
+    script_version => {
+        summary => 'Script version (otherwise will use version from url metadata)',
         schema => 'str',
     },
     url => {
@@ -231,7 +229,7 @@ sub gen_inline_pericmd_script {
 
     my $validate_args = $args{validate_args} // 1;
     #my $validate_result = $args{validate_result} // 1;
-    my $program_name = $args{program_name};
+    my $script_name = $args{script_name};
 
     my $meta;
     my $mod;
@@ -253,7 +251,7 @@ sub gen_inline_pericmd_script {
                 or return [412, "Can't find meta for URL '$url'"];
             defined &{"$mod\::$short_func_name"}
                 or return [412, "Can't find function for URL '$url'"];
-            $program_name //= do {
+            $script_name //= do {
                 local $_ = $short_func_name;
                 s/_/-/g;
                 $_;
@@ -262,14 +260,14 @@ sub gen_inline_pericmd_script {
         } else {
             $meta = $args{meta};
             $func_name = $args{sub_name};
-            $program_name //= do {
+            $script_name //= do {
                 local $_ = $args{sub_name};
                 s/_/-/g;
                 $_;
             };
         }
 
-        $program_name //= do {
+        $script_name //= do {
             local $_ = $0;
             s!.+[/\\]!!;
             $_;
@@ -623,15 +621,15 @@ _
                         my $res = Perinci::CmdLine::Help::gen_help(
                             meta => $meta,
                             common_opts => \%copts,
-                            program_name => $program_name,
+                            program_name => $script_name,
                         );
                         return [500, "Can't generate help: $res->[0] - $res->[1]"]
                             unless $res->[0] == 200;
                         push @l, '        print ', dmp($res->[2]), '; exit 0;', "\n";
                     } elsif ($specmeta->{common_opt} eq 'version') {
                         no strict 'refs';
-                        push @l, '        print "', $program_name , ' version ',
-                            (defined($args{program_version}) ? $args{program_version} :
+                        push @l, '        print "', $script_name , ' version ',
+                            (defined($args{script_version}) ? $args{script_version} :
                              $mod && ${"$mod\::VERSION"} ? ${"$mod\::VERSION"} : '?'),
                             ($mod && ${"$mod\::DATE"} ? " (".${"$mod\::DATE"}.")" : ''),
                             '\n";', "\n";
@@ -754,9 +752,9 @@ _
             # for dzil
             "# DATE\n",
             "# VERSION\n",
-            "# PODNAME: ", ($args{program_name} // ''), "\n",
+            "# PODNAME: ", ($args{script_name} // ''), "\n",
             do {
-                my $abstract = $args{summary} // $meta->{summary};
+                my $abstract = $args{script_summary} // $meta->{summary};
                 if ($abstract) {
                     ("# ABSTRACT: ", $abstract, "\n");
                 } else {
@@ -842,7 +840,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.20 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-10.
+This document describes version 0.21 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-12.
 
 =head1 SYNOPSIS
 
@@ -868,23 +866,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                   Rate  run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           12.854+-0.019/s            --               -61.1%      -82.1%         -89.0%                 -91.7%      -93.7% -97.6%
- run --version (lite)         33+-0.1/s 156.75+-0.87%                   --      -54.0%         -71.7%                 -78.6%      -83.9% -93.9%
- -c (lite)                 71.73+-0.3/s     458+-2.4%          117.3+-1.1%          --         -38.6%                 -53.5%      -65.1% -86.8%
- run 1 (inline)          116.76+-0.99/s   808.3+-7.8%          253.8+-3.2%  62.8+-1.5%             --                 -24.2%      -43.2% -78.4%
- run --version (inline)  154.09+-0.58/s  1098.8+-4.9%          366.9+-2.3% 114.8+-1.2%       32+-1.2%                     --      -25.0% -71.5%
- -c (inline)               205.5+-1.4/s     1498+-11%          522.5+-4.6% 186.4+-2.3%       76+-1.9%               33.3+-1%          -- -62.1%
- perl                        541.5+-4/s     4113+-32%            1541+-13%   655+-6.4%    363.8+-5.2%            251.5+-2.9% 163.6+-2.7%     --
+                                   Rate  run 1 (lite) run --version (lite)     -c (lite) run 1 (inline) run --version (inline)   -c (inline)   perl
+ run 1 (lite)            9.855+-0.011/s            --               -57.4%        -77.8%         -83.5%                 -85.0%        -88.7% -94.5%
+ run --version (lite)    23.108+-0.02/s 134.48+-0.34%                   --        -48.0%         -61.4%                 -64.8%        -73.6% -87.2%
+ -c (lite)              44.407+-0.044/s 350.59+-0.69%         92.17+-0.25%            --         -25.8%                 -32.4%        -49.2% -75.3%
+ run 1 (inline)             59.8+-1.6/s      507+-16%          158.9+-6.9%    34.7+-3.6%             --                  -8.9%        -31.6% -66.7%
+ run --version (inline)    65.7+-0.31/s   566.6+-3.2%          184.3+-1.4%  47.95+-0.71%        9.8+-3%                     --        -24.9% -63.5%
+ -c (inline)            87.452+-0.067/s   787.4+-1.2%        278.45+-0.43%  96.93+-0.25%     46.2+-3.9%           33.11+-0.64%            -- -51.4%
+ perl                    179.89+-0.33/s  1725.4+-3.9%          678.5+-1.6% 305.11+-0.84%      200.7+-8%            173.8+-1.4% 105.71+-0.41%     --
  
  Average times:
-   perl                  :     1.8467ms
-   -c (inline)           :     4.8662ms
-   run --version (inline):     6.4897ms
-   run 1 (inline)        :     8.5646ms
-   -c (lite)             :    13.9412ms
-   run --version (lite)  :    30.3030ms
-   run 1 (lite)          :    77.7968ms
+   perl                  :     5.5590ms
+   -c (inline)           :    11.4348ms
+   run --version (inline):    15.2207ms
+   run 1 (inline)        :    16.7224ms
+   -c (lite)             :    22.5190ms
+   run --version (lite)  :    43.2751ms
+   run 1 (lite)          :   101.4713ms
 
 =head1 FUNCTIONS
 
@@ -1028,14 +1026,6 @@ Set output file, defaults to stdout.
 
 Whether to pass Perinci::CmdLine::Inline object.
 
-=item * B<program_name> => I<str>
-
-Program name.
-
-=item * B<program_version> => I<str>
-
-Program version (otherwise will use version from url metadata).
-
 =item * B<read_config> => I<any>
 
 Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
@@ -1056,6 +1046,18 @@ Currently does nothing, provided only for compatibility with Perinci::CmdLine::B
 
 Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
+=item * B<script_name> => I<str>
+
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+
+=item * B<script_summary> => I<str>
+
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+
+=item * B<script_version> => I<str>
+
+Script version (otherwise will use version from url metadata).
+
 =item * B<shebang> => I<str>
 
 Set shebang line.
@@ -1070,10 +1072,6 @@ Assume that function returns raw text that need no formatting, do not offer --fo
 
 Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
-=item * B<summary> => I<str>
-
-Program summary.
-
 =item * B<tags> => I<any>
 
 Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
